@@ -101,7 +101,7 @@ typedef enum {
 	NM_STATE_CONNECTING       = 40,
 	NM_STATE_CONNECTED_LOCAL  = 50,
 	NM_STATE_CONNECTED_SITE   = 60,
-	NM_STATE_CONNECTED_GLOBAL = 70
+	NM_STATE_CONNECTED_GLOBAL = 70,
 } NMState;
 
 /* For backwards compat */
@@ -121,11 +121,11 @@ typedef enum {
  * Since: 0.9.8.6
  */
 typedef enum {
-	NM_CONNECTIVITY_UNKNOWN,
-	NM_CONNECTIVITY_NONE,
-	NM_CONNECTIVITY_PORTAL,
-	NM_CONNECTIVITY_LIMITED,
-	NM_CONNECTIVITY_FULL
+	NM_CONNECTIVITY_UNKNOWN = 0,
+	NM_CONNECTIVITY_NONE    = 1,
+	NM_CONNECTIVITY_PORTAL  = 2,
+	NM_CONNECTIVITY_LIMITED = 3,
+	NM_CONNECTIVITY_FULL    = 4,
 } NMConnectivityState;
 
 /**
@@ -240,7 +240,7 @@ typedef enum { /*< flags >*/
  **/
 typedef enum { /*< underscore_name=nm_802_11_ap_flags, flags >*/
 	NM_802_11_AP_FLAGS_NONE    = 0x00000000,
-	NM_802_11_AP_FLAGS_PRIVACY = 0x00000001
+	NM_802_11_AP_FLAGS_PRIVACY = 0x00000001,
 } NM80211ApFlags;
 
 /**
@@ -279,7 +279,7 @@ typedef enum { /*< underscore_name=nm_802_11_ap_security_flags, flags >*/
 	NM_802_11_AP_SEC_GROUP_TKIP      = 0x00000040,
 	NM_802_11_AP_SEC_GROUP_CCMP      = 0x00000080,
 	NM_802_11_AP_SEC_KEY_MGMT_PSK    = 0x00000100,
-	NM_802_11_AP_SEC_KEY_MGMT_802_1X = 0x00000200
+	NM_802_11_AP_SEC_KEY_MGMT_802_1X = 0x00000200,
 } NM80211ApSecurityFlags;
 
 /**
@@ -299,9 +299,9 @@ typedef enum { /*< underscore_name=nm_802_11_ap_security_flags, flags >*/
  **/
 typedef enum { /*< underscore_name=nm_802_11_mode >*/
 	NM_802_11_MODE_UNKNOWN = 0,
-	NM_802_11_MODE_ADHOC,
-	NM_802_11_MODE_INFRA,
-	NM_802_11_MODE_AP
+	NM_802_11_MODE_ADHOC   = 1,
+	NM_802_11_MODE_INFRA   = 2,
+	NM_802_11_MODE_AP      = 3,
 } NM80211Mode;
 
 /**
@@ -395,7 +395,7 @@ typedef enum {
 	NM_DEVICE_STATE_SECONDARIES  = 90,
 	NM_DEVICE_STATE_ACTIVATED    = 100,
 	NM_DEVICE_STATE_DEACTIVATING = 110,
-	NM_DEVICE_STATE_FAILED       = 120
+	NM_DEVICE_STATE_FAILED       = 120,
 } NMDeviceState;
 
 
@@ -468,71 +468,71 @@ typedef enum {
  * Device state change reason codes
  */
 typedef enum {
-	NM_DEVICE_STATE_REASON_NONE = 0,
-	NM_DEVICE_STATE_REASON_UNKNOWN = 1,
-	NM_DEVICE_STATE_REASON_NOW_MANAGED = 2,
-	NM_DEVICE_STATE_REASON_NOW_UNMANAGED = 3,
-	NM_DEVICE_STATE_REASON_CONFIG_FAILED = 4,
-	NM_DEVICE_STATE_REASON_IP_CONFIG_UNAVAILABLE = 5,
-	NM_DEVICE_STATE_REASON_IP_CONFIG_EXPIRED = 6,
-	NM_DEVICE_STATE_REASON_NO_SECRETS = 7,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_DISCONNECT = 8,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_CONFIG_FAILED = 9,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_FAILED = 10,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_TIMEOUT = 11,
-	NM_DEVICE_STATE_REASON_PPP_START_FAILED = 12,
-	NM_DEVICE_STATE_REASON_PPP_DISCONNECT = 13,
-	NM_DEVICE_STATE_REASON_PPP_FAILED = 14,
-	NM_DEVICE_STATE_REASON_DHCP_START_FAILED = 15,
-	NM_DEVICE_STATE_REASON_DHCP_ERROR = 16,
-	NM_DEVICE_STATE_REASON_DHCP_FAILED = 17,
-	NM_DEVICE_STATE_REASON_SHARED_START_FAILED = 18,
-	NM_DEVICE_STATE_REASON_SHARED_FAILED = 19,
-	NM_DEVICE_STATE_REASON_AUTOIP_START_FAILED = 20,
-	NM_DEVICE_STATE_REASON_AUTOIP_ERROR = 21,
-	NM_DEVICE_STATE_REASON_AUTOIP_FAILED = 22,
-	NM_DEVICE_STATE_REASON_MODEM_BUSY = 23,
-	NM_DEVICE_STATE_REASON_MODEM_NO_DIAL_TONE = 24,
-	NM_DEVICE_STATE_REASON_MODEM_NO_CARRIER = 25,
-	NM_DEVICE_STATE_REASON_MODEM_DIAL_TIMEOUT = 26,
-	NM_DEVICE_STATE_REASON_MODEM_DIAL_FAILED = 27,
-	NM_DEVICE_STATE_REASON_MODEM_INIT_FAILED = 28,
-	NM_DEVICE_STATE_REASON_GSM_APN_FAILED = 29,
+	NM_DEVICE_STATE_REASON_NONE                           = 0,
+	NM_DEVICE_STATE_REASON_UNKNOWN                        = 1,
+	NM_DEVICE_STATE_REASON_NOW_MANAGED                    = 2,
+	NM_DEVICE_STATE_REASON_NOW_UNMANAGED                  = 3,
+	NM_DEVICE_STATE_REASON_CONFIG_FAILED                  = 4,
+	NM_DEVICE_STATE_REASON_IP_CONFIG_UNAVAILABLE          = 5,
+	NM_DEVICE_STATE_REASON_IP_CONFIG_EXPIRED              = 6,
+	NM_DEVICE_STATE_REASON_NO_SECRETS                     = 7,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_DISCONNECT          = 8,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_CONFIG_FAILED       = 9,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_FAILED              = 10,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_TIMEOUT             = 11,
+	NM_DEVICE_STATE_REASON_PPP_START_FAILED               = 12,
+	NM_DEVICE_STATE_REASON_PPP_DISCONNECT                 = 13,
+	NM_DEVICE_STATE_REASON_PPP_FAILED                     = 14,
+	NM_DEVICE_STATE_REASON_DHCP_START_FAILED              = 15,
+	NM_DEVICE_STATE_REASON_DHCP_ERROR                     = 16,
+	NM_DEVICE_STATE_REASON_DHCP_FAILED                    = 17,
+	NM_DEVICE_STATE_REASON_SHARED_START_FAILED            = 18,
+	NM_DEVICE_STATE_REASON_SHARED_FAILED                  = 19,
+	NM_DEVICE_STATE_REASON_AUTOIP_START_FAILED            = 20,
+	NM_DEVICE_STATE_REASON_AUTOIP_ERROR                   = 21,
+	NM_DEVICE_STATE_REASON_AUTOIP_FAILED                  = 22,
+	NM_DEVICE_STATE_REASON_MODEM_BUSY                     = 23,
+	NM_DEVICE_STATE_REASON_MODEM_NO_DIAL_TONE             = 24,
+	NM_DEVICE_STATE_REASON_MODEM_NO_CARRIER               = 25,
+	NM_DEVICE_STATE_REASON_MODEM_DIAL_TIMEOUT             = 26,
+	NM_DEVICE_STATE_REASON_MODEM_DIAL_FAILED              = 27,
+	NM_DEVICE_STATE_REASON_MODEM_INIT_FAILED              = 28,
+	NM_DEVICE_STATE_REASON_GSM_APN_FAILED                 = 29,
 	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_NOT_SEARCHING = 30,
-	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_DENIED = 31,
-	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_TIMEOUT = 32,
-	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_FAILED = 33,
-	NM_DEVICE_STATE_REASON_GSM_PIN_CHECK_FAILED = 34,
-	NM_DEVICE_STATE_REASON_FIRMWARE_MISSING = 35,
-	NM_DEVICE_STATE_REASON_REMOVED = 36,
-	NM_DEVICE_STATE_REASON_SLEEPING = 37,
-	NM_DEVICE_STATE_REASON_CONNECTION_REMOVED = 38,
-	NM_DEVICE_STATE_REASON_USER_REQUESTED = 39,
-	NM_DEVICE_STATE_REASON_CARRIER = 40,
-	NM_DEVICE_STATE_REASON_CONNECTION_ASSUMED = 41,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_AVAILABLE = 42,
-	NM_DEVICE_STATE_REASON_MODEM_NOT_FOUND = 43,
-	NM_DEVICE_STATE_REASON_BT_FAILED = 44,
-	NM_DEVICE_STATE_REASON_GSM_SIM_NOT_INSERTED = 45,
-	NM_DEVICE_STATE_REASON_GSM_SIM_PIN_REQUIRED = 46,
-	NM_DEVICE_STATE_REASON_GSM_SIM_PUK_REQUIRED = 47,
-	NM_DEVICE_STATE_REASON_GSM_SIM_WRONG = 48,
-	NM_DEVICE_STATE_REASON_INFINIBAND_MODE = 49,
-	NM_DEVICE_STATE_REASON_DEPENDENCY_FAILED = 50,
-	NM_DEVICE_STATE_REASON_BR2684_FAILED = 51,
-	NM_DEVICE_STATE_REASON_MODEM_MANAGER_UNAVAILABLE = 52,
-	NM_DEVICE_STATE_REASON_SSID_NOT_FOUND = 53,
-	NM_DEVICE_STATE_REASON_SECONDARY_CONNECTION_FAILED = 54,
-	NM_DEVICE_STATE_REASON_DCB_FCOE_FAILED = 55,
-	NM_DEVICE_STATE_REASON_TEAMD_CONTROL_FAILED = 56,
-	NM_DEVICE_STATE_REASON_MODEM_FAILED = 57,
-	NM_DEVICE_STATE_REASON_MODEM_AVAILABLE = 58,
-	NM_DEVICE_STATE_REASON_SIM_PIN_INCORRECT = 59,
-	NM_DEVICE_STATE_REASON_NEW_ACTIVATION = 60,
-	NM_DEVICE_STATE_REASON_PARENT_CHANGED = 61,
-	NM_DEVICE_STATE_REASON_PARENT_MANAGED_CHANGED = 62,
+	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_DENIED        = 31,
+	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_TIMEOUT       = 32,
+	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_FAILED        = 33,
+	NM_DEVICE_STATE_REASON_GSM_PIN_CHECK_FAILED           = 34,
+	NM_DEVICE_STATE_REASON_FIRMWARE_MISSING               = 35,
+	NM_DEVICE_STATE_REASON_REMOVED                        = 36,
+	NM_DEVICE_STATE_REASON_SLEEPING                       = 37,
+	NM_DEVICE_STATE_REASON_CONNECTION_REMOVED             = 38,
+	NM_DEVICE_STATE_REASON_USER_REQUESTED                 = 39,
+	NM_DEVICE_STATE_REASON_CARRIER                        = 40,
+	NM_DEVICE_STATE_REASON_CONNECTION_ASSUMED             = 41,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_AVAILABLE           = 42,
+	NM_DEVICE_STATE_REASON_MODEM_NOT_FOUND                = 43,
+	NM_DEVICE_STATE_REASON_BT_FAILED                      = 44,
+	NM_DEVICE_STATE_REASON_GSM_SIM_NOT_INSERTED           = 45,
+	NM_DEVICE_STATE_REASON_GSM_SIM_PIN_REQUIRED           = 46,
+	NM_DEVICE_STATE_REASON_GSM_SIM_PUK_REQUIRED           = 47,
+	NM_DEVICE_STATE_REASON_GSM_SIM_WRONG                  = 48,
+	NM_DEVICE_STATE_REASON_INFINIBAND_MODE                = 49,
+	NM_DEVICE_STATE_REASON_DEPENDENCY_FAILED              = 50,
+	NM_DEVICE_STATE_REASON_BR2684_FAILED                  = 51,
+	NM_DEVICE_STATE_REASON_MODEM_MANAGER_UNAVAILABLE      = 52,
+	NM_DEVICE_STATE_REASON_SSID_NOT_FOUND                 = 53,
+	NM_DEVICE_STATE_REASON_SECONDARY_CONNECTION_FAILED    = 54,
+	NM_DEVICE_STATE_REASON_DCB_FCOE_FAILED                = 55,
+	NM_DEVICE_STATE_REASON_TEAMD_CONTROL_FAILED           = 56,
+	NM_DEVICE_STATE_REASON_MODEM_FAILED                   = 57,
+	NM_DEVICE_STATE_REASON_MODEM_AVAILABLE                = 58,
+	NM_DEVICE_STATE_REASON_SIM_PIN_INCORRECT              = 59,
+	NM_DEVICE_STATE_REASON_NEW_ACTIVATION                 = 60,
+	NM_DEVICE_STATE_REASON_PARENT_CHANGED                 = 61,
+	NM_DEVICE_STATE_REASON_PARENT_MANAGED_CHANGED         = 62,
 
-	NM_DEVICE_STATE_REASON_LAST = 0xFFFF
+	NM_DEVICE_STATE_REASON_LAST                           = 0xFFFF,
 } NMDeviceStateReason;
 
 
@@ -551,11 +551,11 @@ typedef enum {
  * network.
  **/
 typedef enum {
-	NM_ACTIVE_CONNECTION_STATE_UNKNOWN = 0,
-	NM_ACTIVE_CONNECTION_STATE_ACTIVATING,
-	NM_ACTIVE_CONNECTION_STATE_ACTIVATED,
-	NM_ACTIVE_CONNECTION_STATE_DEACTIVATING,
-	NM_ACTIVE_CONNECTION_STATE_DEACTIVATED
+	NM_ACTIVE_CONNECTION_STATE_UNKNOWN      = 0,
+	NM_ACTIVE_CONNECTION_STATE_ACTIVATING   = 1,
+	NM_ACTIVE_CONNECTION_STATE_ACTIVATED    = 2,
+	NM_ACTIVE_CONNECTION_STATE_DEACTIVATING = 3,
+	NM_ACTIVE_CONNECTION_STATE_DEACTIVATED  = 4,
 } NMActiveConnectionState;
 
 #endif /* NETWORK_MANAGER_H */
